ArrayVec

Struct ArrayVec 

pub struct ArrayVec<T, const N: usize> { /* private fields */ }
A fixed-capacity vector.

Implementations

Source

impl<T, const N: usize> ArrayVec<T, N>

pub const fn new() -> Self

Creates an empty vector.

pub fn try_push(&mut self, value: T) -> Result<(), ArrayVecError>

Appends a value, returning an error when the vector is full.

pub fn push(&mut self, value: T)

Appends a value.

Panics

Panics when the vector is full.

pub fn len(&self) -> usize

Returns the number of stored values.

pub fn is_empty(&self) -> bool

Returns whether the vector is empty.

pub fn as_slice(&self) -> &[T]

Returns the stored values as a slice.

pub fn as_mut_slice(&mut self) -> &mut [T]

Returns the stored values as a mutable slice.

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over the stored values.

pub fn iter_mut(&mut self) -> IterMut<'_, T>

Returns a mutable iterator over the stored values.

pub fn reverse(&mut self)

Reverses the stored values.

pub fn as_ptr(&self) -> *const T

Returns a pointer to the vector’s storage.

pub fn as_mut_ptr(&mut self) -> *mut T

Returns a mutable pointer to the vector’s storage.

Source

impl<T, const N: usize> ArrayVec<T, N>
where T: Copy + PartialEq,

pub fn contains(&self, value: &T) -> bool

Returns whether the vector contains the given value.

Source

impl<T, const N: usize> ArrayVec<T, N>
where T: Copy + Ord,

pub fn sort_unstable(&mut self)

Sorts the vector without preserving the order of equal values.