pub struct RingBuf<T: Copy, const N: usize> { /* private fields */ }Expand description
A fixed-capacity FIFO ring buffer.
A buffer with storage size N can hold at most N - 1 values.
Implementations
Sourceimpl<T: Copy, const N: usize> RingBuf<T, N>
impl<T: Copy, const N: usize> RingBuf<T, N>
Sourcepub const fn max_capacity(&self) -> usize
pub const fn max_capacity(&self) -> usize
Returns the maximum number of values the buffer can hold.
Sourcepub fn try_push(&mut self, value: T) -> Result<(), T>
pub fn try_push(&mut self, value: T) -> Result<(), T>
Appends a value, returning it when the buffer is full.
Sourcepub unsafe fn push_unchecked(&mut self, value: T)
pub unsafe fn push_unchecked(&mut self, value: T)
Appends a value without checking whether the buffer is full.
Safety
The caller must ensure the buffer is not full.